import React from "react"
import PropTypes from "prop-types"
import Ripple from "@wsdm/ui-ripple"

const Button = ({
  ripple,
  rounded,
  raised,
  outlined,
  rippleColor,
  children,
  className,
  style,
  onClick,
}) => (
  <button
    className={`
      relative
      btn
      overflow-hidden
      ${rounded ? "border-radius-2" : "border-radius-0"}
      ${raised ? "btn--raised" : ""}
      ${outlined ? "btn--outlined" : "border-none"}
      ${className || (outlined ? "px1" : "px1 py05")}
    `}
    style={style}
    onClick={onClick}
  >
    {children}
    {ripple && <Ripple color={rippleColor || "rgba(0,0,0,0.2)"} />}
  </button>
)

Button.propTypes = {
  ripple: PropTypes.bool,
  rounded: PropTypes.bool,
  raised: PropTypes.bool,
  outlined: PropTypes.bool,
  rippleColor: PropTypes.string,
  children: PropTypes.oneOfType([
    PropTypes.arrayOf(PropTypes.node),
    PropTypes.node,
  ]),
  className: PropTypes.string,
  style: PropTypes.object,
  onClick: PropTypes.func,
}

Button.defaultProps = {
  rounded: true,
}

export default Button
